@@ -161,7 +161,7 @@ static R_CallMethodDef callMethods[] = {
 #endif
 	ENTRY(RS_XML_getDTD, 5),
 	ENTRY(RS_XML_libxmlVersion, 0),
-	ENTRY(RS_XML_Parse, 17),
+	ENTRY(RS_XML_Parse, 18),
 	ENTRY(RS_XML_ParseTree, 21),
 	ENTRY(R_newXMLDtd, 5),
 	ENTRY(R_newXMLDoc, 3),
@@ -201,7 +201,7 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_setKeepBlanksDefault, 1),
 	ENTRY(R_getDocEncoding, 1),
 	ENTRY(R_getLineNumber, 1),
-        ENTRY(RS_XML_xpathEval, 7),
+        ENTRY(RS_XML_xpathEval, 9),
         ENTRY(RS_XML_xmlNodeChildrenReferences, 3),
 	ENTRY(RS_XML_freeDoc, 1),
 	ENTRY(RS_XML_setRootNode, 2),
@@ -245,6 +245,7 @@ static R_CallMethodDef callMethods[] = {
 	ENTRY(RS_XML_xmlXIncludeProcessFlags, 2),
 	ENTRY(RS_XML_xmlXIncludeProcessTreeFlags, 2),
 	ENTRY(R_convertXMLNsRef, 1),
+	ENTRY(R_replaceNodeWithChildren, 1),
 	{NULL, NULL, 0}
 };
 
@@ -306,8 +307,7 @@ RS_XML_setStructuredErrorHandler(SEXP els)
     sym = VECTOR_ELT(els, 1);
 
     if(sym != R_NilValue && TYPEOF(sym) != EXTPTRSXP) {
-	PROBLEM "invalid symbol object for XML error handler. Need an external pointer, e.g from getNativeSymbolInfo"
-        ERROR;
+	Rf_error("invalid symbol object for XML error handler. Need an external pointer, e.g from getNativeSymbolInfo");
     }
 
     if(fun == R_NilValue)
@@ -361,7 +361,7 @@ R_lookString(SEXP rstr)
 {
     const char *str;
     str = CHAR(STRING_ELT(rstr, 0));
-    return(ScalarInteger(strlen(str)));
+    return(ScalarInteger((int) strlen(str)));
 }
 
 
